@@ -24,7 +24,10 @@ def JsonToBytes(myjson):
 
 def JsonToStr(myjson, indent=4, sort_keys=True):
     if isinstance(myjson, dict):
-        return json.dumps(myjson, indent=indent, sort_keys=sort_keys)
+        if indent == 0:
+            return json.dumps(myjson, indent=indent, sort_keys=sort_keys).replace('\n','')
+        else:
+            return json.dumps(myjson, indent=indent, sort_keys=sort_keys)
     else:
         raise Exception(f'{myjson} must by dict')
 
