@@ -126,7 +126,7 @@ class Chat_user_userManager(AuditManager):
 
         with transaction.atomic():
             props = data.get('props')
-            if data.get('compulsory_reading') is True:
+            if data.get('compulsory_reading') == True:
                 props |= Chat_user_user.props.compulsory_reading
             else:
                 props &= ~Chat_user_user.props.compulsory_reading
